pybmix package
==============


Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pybmix.core
   pybmix.estimators
   pybmix.proto
   pybmix.utils

Submodules
----------

pybmix.example module
---------------------

.. automodule:: pybmix.example
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pybmix
   :members:
   :undoc-members:
   :show-inheritance:
